@@ -3,9 +3,8 @@ use 5.008001;
 use strict;
 use warnings;
 require Algorithm::SAT::Backtracking;
-use Storable qw(dclone);
 use Carp qw(croak);
-our $VERSION = "0.08";
+our $VERSION = "0.09";
 
 # Boolean expression builder.  Note that the connector for clauses is `OR`;
 # so, when calling the instance methods `xor`, `and`, and `or`, the clauses
@@ -35,7 +34,6 @@ sub with {
 sub or {
     my $self = shift;
     $self->_ensure(@_);
-    my $or = dclone( \@_ );
     push( @{ $self->{_expr} }, [@_] );
     return $self;
 }
